Quickly import and export delimited data with Django support for PostgreSQL’s COPY command

|Build Status| |PyPI version| |Documentation Status|

-  Documentation:
   `django-postgres-copy.readthedocs.io <https://django-postgres-copy.readthedocs.io/en/latest/>`__
-  Issues:
   `github.com/california-civic-data-coalition/django-postgres-copy/issues <https://github.com/california-civic-data-coalition/django-postgres-copy/issues>`__
-  Packaging:
   `pypi.python.org/pypi/django-postgres-copy <https://pypi.python.org/pypi/django-postgres-copy>`__
-  Testing:
   `github.com/california-civic-data-coalition/django-postgres-copy/actions <https://github.com/california-civic-data-coalition/django-postgres-copy/actions/workflows/test.yaml>`__

.. |Build Status| image:: https://github.com/california-civic-data-coalition/django-postgres-copy/actions/workflows/test.yaml/badge.svg
    :target: https://github.com/california-civic-data-coalition/django-postgres-copy/actions/workflows/test.yaml
.. |PyPI version| image:: https://badge.fury.io/py/django-postgres-copy.svg
    :target: https://badge.fury.io/py/django-postgres-copy
.. |Documentation Status| image:: https://readthedocs.org/projects/django-postgres-copy/badge/
   :target: http://django-postgres-copy.californiacivicdata.org
